##  Changing Existing Links to Fact Sheets
You can change the link between a discovered item and a fact sheet if the link was added by mistake or if a more suitable option is available.
To change a link, do the following:
  1. Choose the name of a discovered item to open the side panel.
  2. Hover over the linked application fact sheet and choose Edit.
  3. Search for and select the desired fact sheet.
  4. Choose Link.


**Note**
To reject a previously linked item without making changes, choose Reject.
